==> vue-hooks-1.1.1.tgz: package/lib/use-event-listener/use-event-listener.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  __markAsModule(target);
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __reExport = (target, module2, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && key !== "default")
        __defProp(target, key, { get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable });
  }
  return target;
};
var __toModule = (module2) => {
  return __reExport(__markAsModule(__defProp(module2 != null ? __create(__getProtoOf(module2)) : {}, "default", module2 && module2.__esModule && "default" in module2 ? { get: () => module2.default, enumerable: true } : { value: module2, enumerable: true })), module2);
};
__export(exports, {
  useEventListener: () => useEventListener
});
var import_vue = __toModule(require("vue"));
const useEventListener = (event, listener, options = {}) => {
  const _a = options, { target = window } = _a, rest = __objRest(_a, ["target"]);
  const remove = (el) => {
    const _el = (0, import_vue.unref)(el);
    _el && _el.removeEventListener(event, listener, rest);
  };
  const add = (el) => {
    const _el = (0, import_vue.unref)(el);
    _el && _el.addEventListener(event, listener, rest);
  };
  (0, import_vue.watch)(() => (0, import_vue.unref)(target), (el, prevEl) => {
    remove(prevEl);
    add(el);
  });
  (0, import_vue.onMounted)(() => add(target));
  (0, import_vue.onDeactivated)(() => remove(target));
  (0, import_vue.onBeforeUnmount)(() => remove(target));
};

==> vue-hooks-1.3.0.tgz: package/lib/use-event-listener/use-event-listener.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  useEventListener: () => useEventListener
});
module.exports = __toCommonJS(stdin_exports);
var import_vue = require("vue");
const useEventListener = (event, listener, options = {}) => {
  const _a = options, { target = window } = _a, rest = __objRest(_a, ["target"]);
  const remove = (el) => {
    const _el = (0, import_vue.unref)(el);
    _el && _el.removeEventListener(event, listener, rest);
  };
  const add = (el) => {
    const _el = (0, import_vue.unref)(el);
    _el && _el.addEventListener(event, listener, rest);
  };
  (0, import_vue.watch)(() => (0, import_vue.unref)(target), (el, prevEl) => {
    remove(prevEl);
    add(el);
  });
  (0, import_vue.onMounted)(() => add(target));
  (0, import_vue.onDeactivated)(() => remove(target));
  (0, import_vue.onBeforeUnmount)(() => remove(target));
};
